@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkGeodesicActiveContourShapePriorLevelSetFunction.h,v $
+  Module:    itkGeodesicActiveContourShapePriorLevelSetFunction.h
   Language:  C++
-  Date:      $Date: 2008-12-21 19:13:12 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
