@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkHoughTransform2DCirclesImageFilter.h,v $
+  Module:    itkHoughTransform2DCirclesImageFilter.h
   Language:  C++
-  Date:      $Date: 2010-02-03 18:53:41 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
