@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBSplineDeformableTransform.h,v $
+  Module:    itkBSplineDeformableTransform.h
   Language:  C++
-  Date:      $Date: 2010-03-05 15:26:30 $
-  Version:   $Revision: 1.42 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
