@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBarrier.cxx,v $
+  Module:    itkBarrier.cxx
   Language:  C++
-  Date:      $Date: 2006-03-16 22:07:44 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
