@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkFiniteDifferenceSparseImageFilter.h,v $
+  Module:    itkFiniteDifferenceSparseImageFilter.h
   Language:  C++
-  Date:      $Date: 2009-04-25 12:24:07 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
