@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkMacro.h,v $
+  Module:    itkMacro.h
   Language:  C++
-  Date:      $Date: 2010-04-26 14:32:50 $
-  Version:   $Revision: 1.101 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
