@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkWin32OutputWindow.h,v $
+  Module:    itkWin32OutputWindow.h
   Language:  C++
-  Date:      $Date: 2006-03-18 18:06:38 $
-  Version:   $Revision: 1.26 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
