@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBMPImageIOFactory.cxx,v $
+  Module:    itkBMPImageIOFactory.cxx
   Language:  C++
-  Date:      $Date: 2004/02/20 17:04:32 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -49,4 +49,3 @@ BMPImageIOFactory::GetDescription() const
 }
 
 } // end namespace itk
-
