@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBrains2MaskImageIO.cxx,v $
+  Module:    itkBrains2MaskImageIO.cxx
   Language:  C++
-  Date:      $Date: 2009-02-07 05:23:54 $
-  Version:   $Revision: 1.32 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
