@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkFEMMaterials.h,v $
+  Module:    itkFEMMaterials.h
   Language:  C++
-  Date:      $Date: 2009-01-30 21:10:19 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
