@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itpack.h,v $
+  Module:    itpack.h
   Language:  C++
-  Date:      $Date: 2006-11-07 23:23:16 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
