@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkVersorRigid3DTransformOptimizer.h,v $
+  Module:    itkVersorRigid3DTransformOptimizer.h
   Language:  C++
-  Date:      $Date: 2007-03-22 14:29:14 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
