@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: MeshKComplex.cxx,v $
+  Module:    MeshKComplex.cxx
   Language:  C++
-  Date:      $Date: 2009-03-17 21:11:44 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
