@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: ThresholdImageFilter.cxx,v $
+  Module:    ThresholdImageFilter.cxx
   Language:  C++
-  Date:      $Date: 2005-08-31 13:55:22 $
-  Version:   $Revision: 1.28 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
