@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: ModelToImageRegistration1.cxx,v $
+  Module:    ModelToImageRegistration1.cxx
   Language:  C++
-  Date:      $Date: 2009-06-24 12:09:29 $
-  Version:   $Revision: 1.43 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
