@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: SpatialObjectTreeContainer.cxx,v $
+  Module:    SpatialObjectTreeContainer.cxx
   Language:  C++
-  Date:      $Date: 2005-04-02 21:46:14 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
