@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkCurvesLevelSetImageFilterZeroSigmaTest.cxx,v $
+  Module:    itkCurvesLevelSetImageFilterZeroSigmaTest.cxx
   Language:  C++
-  Date:      $Date: 2005-04-17 17:00:36 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
