@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBilateralImageFilterTest3.cxx,v $
+  Module:    itkBilateralImageFilterTest3.cxx
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
