@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkBinaryDilateImageFilterTest3.cxx,v $
+  Module:    itkBinaryDilateImageFilterTest3.cxx
   Language:  C++
-  Date:      $Date: 2007-01-26 09:44:16 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
