@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkCompose3DCovariantVectorImageFilterTest.cxx,v $
+  Module:    itkCompose3DCovariantVectorImageFilterTest.cxx
   Language:  C++
-  Date:      $Date: 2006-01-15 04:28:36 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
