@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkSampleMeanShiftClusteringFilterTest.cxx,v $
+  Module:    itkSampleMeanShiftClusteringFilterTest.cxx
   Language:  C++
-  Date:      $Date: 2005-02-08 03:18:41 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
