@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: itkQuadEdgeMeshMeanCurvatureTest.cxx,v $
+  Module:    itkQuadEdgeMeshMeanCurvatureTest.cxx
   Language:  C++
-  Date:      $Date: 2009-12-19 20:56:32 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
