@@ -1,10 +1,10 @@
 /*=========================================================================
                                                                                 
   Program:   gdcm
-  Module:    $RCSfile: gdcmDocEntry.h,v $
+  Module:    gdcmDocEntry.h
   Language:  C++
-  Date:      $Date: 2006-07-10 20:08:21 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date$
+  Version:   $Revision$
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
