@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: wrap_itkCurvesLevelSetImageFilter.cxx,v $
+  Module:    wrap_itkCurvesLevelSetImageFilter.cxx
   Language:  C++
-  Date:      $Date: 2003/09/10 14:30:12 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
